@@ -287,7 +287,7 @@ typedef enum
   ATK_ROLE_RULER,
   ATK_ROLE_APPLICATION,
   ATK_ROLE_AUTOCOMPLETE,
-  ATK_ROLE_EDITBAR,
+  ATK_ROLE_EDITBAR,          /*<nick=edit-bar>*/
   ATK_ROLE_EMBEDDED,
   ATK_ROLE_ENTRY,
   ATK_ROLE_CHART,
